// src/app/context/AuthContext.js
"use client"; // Mark this as a client component

import { createContext, useContext, useState, useEffect } from "react";
import { account } from "../lib/appwrite"; // Import Appwrite account
import { useRouter } from "next/navigation";

const AuthContext = createContext();

export const AuthProvider = ({ children }) => {
  const [isAuthenticated, setIsAuthenticated] = useState(false);
  const [loading, setLoading] = useState(true);
  const router = useRouter();

  useEffect(() => {
    const checkAuth = async () => {
      try {
        await account.get(); // Check if the user is authenticated
        setIsAuthenticated(true);
      } catch (error) {
        if (error.code === 401) {
          // Session expired or invalid
          localStorage.removeItem("isLoggedIn");
          setIsAuthenticated(false);
          router.push("/signup"); // Redirect to sign-in page
        }
      } finally {
        setLoading(false);
      }
    };

    checkAuth();
  }, [router]);

  return (
    <AuthContext.Provider value={{ isAuthenticated, setIsAuthenticated, loading }}>
      {children}
    </AuthContext.Provider>
  );
};

export const useAuth = () => useContext(AuthContext);