'use client'; // Required for client-side interactivity
import Image from 'next/image';
import { useState, useEffect } from 'react';
import Head from 'next/head';
import Link from 'next/link';

// Import components (you'll need to create these)
import Preloader from "../../components/partials/preloaders";
// import Sidebar from '@/app/partials/sidebar';
import Overlay from "../../components/partials/overlay";
import Header from "../../components/partials/header";

export default function BookingPage() {
    const [darkMode, setDarkMode] = useState(false);
    const [loaded, setLoaded] = useState(false);
    const [appointmentDate, setAppointmentDate] = useState('');

    useEffect(() => {
        // Load dark mode preference from localStorage
        const savedDarkMode = JSON.parse(localStorage.getItem('darkMode'));
        if (savedDarkMode !== null) {
            setDarkMode(savedDarkMode);
        }
        setLoaded(true);
    }, []);

    useEffect(() => {
        // Save dark mode preference to localStorage when it changes
        localStorage.setItem('darkMode', JSON.stringify(darkMode));
    }, [darkMode]);

    if (!loaded) {
        return <Preloader />;
    }

    return (
        <div className={`flex flex-col min-h-screen ${darkMode ? 'dark bg-gray-900' : ''}`}>
            <Head>
                <title>eCommerce Dashboard | TailAdmin - Tailwind CSS Admin Dashboard Template</title>
                <meta charSet="UTF-8" />
                <meta
                    name="viewport"
                    content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0"
                />
                <meta httpEquiv="X-UA-Compatible" content="ie=edge" />
            </Head>

            {/* ===== Page Wrapper Start ===== */}
            <div className="flex h-screen overflow-hidden">
                {/* ===== Sidebar Start ===== */}
                {/* <Sidebar /> */}
                {/* ===== Sidebar End ===== */}

                {/* ===== Content Area Start ===== */}
                <div className="relative flex flex-col flex-1 overflow-x-hidden overflow-y-auto">
                    {/* Small Device Overlay Start */}
                    <Overlay />
                    {/* Small Device Overlay End */}

                    {/* ===== Header Start ===== */}
                    <div darkMode={darkMode} setDarkMode={setDarkMode} className='flex bg-white dark:bg-gray-800 shadow-sm sticky top-0 z-50 w-full'>
                        <Header />
                    </div>
                    {/* ===== Header End ===== */}

                    {/* ===== Main Content Start ===== */}
                    <main>
                        <div className="p-4 mx-auto max-w-[--breakpoint-2xl] md:p-6">
                            <div>
                                <h2 className="text-2xl">Book Appointment</h2>
                                <label htmlFor="appointmentDate">
                                    Date:
                                    <input
                                        type="date"
                                        name="appointmentDate"
                                        id="appointmentDate"
                                        value={appointmentDate}
                                        onChange={(e) => setAppointmentDate(e.target.value)}
                                        className="ml-2"
                                    />
                                </label>
                            </div>

                            <div className="flex flex-col items-center justify-center gap-6 lg:gap-24 lg:flex-row max-w-2xl mx-auto my-20 lg:my-32 lg:max-w-4xl">
                                <div className="lg:w-full">
                                    <img
                                        src="/images/user/appointment-booking-with-calendar 1.png"
                                        alt="Appointment booking illustration"
                                        className="w-full"
                                    />
                                </div>
                                <div className="flex flex-col gap-4 md:flex-row lg:flex-col w-full">
                                    <Link href="/single-booking" className="w-full">
                                        <button
                                            className="inline-flex items-center justify-center gap-2 px-4 py-3 font-medium text-white transition rounded-lg bg-blue-500 shadow-theme-xs hover:bg-blue-600 w-full"
                                        >
                                            <img
                                                src="/images/icons/Vector.png"  
                                                alt="single booking"
                                                className="p-1 text-blue-500"
                                            />
                                            Single
                                        </button>
                                    </Link>
                                    <Link href="/multi-booking" className="w-full">
                                        <button
                                            className="inline-flex items-center justify-center gap-2 px-4 py-3 font-medium text-blue-500 transition rounded-lg bg-white shadow-theme-xs hover:bg-gray-100 border border-gray-400 w-full"
                                        >
                                            
                                                <img
                                                src="/images/icons/Group 1000011641.png"
                                                alt="single booking"
                                                className="p-1 text-blue-500"
                                            />
                                            Bulk Booking
                                        </button>
                                    </Link>
                                </div>
                            </div>

                            <div className="text-center">
                                <p>Note: Token booking is available for current date only i.e. Today</p>
                            </div>
                        </div>
                    </main>
                    {/* ===== Main Content End ===== */}
                </div>
                {/* ===== Content Area End ===== */}
            </div>
            {/* ===== Page Wrapper End ===== */}
        </div>
    );
}